==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeFluent<A extends ACMEChallengeFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeFluent() {
  }
  public ACMEChallengeFluent(ACMEChallenge instance) {
    instance = (instance != null ? instance : new ACMEChallenge());

    if (instance != null) {
      this.withToken(instance.getToken());
      this.withType(instance.getType());
      this.withUrl(instance.getUrl());
      this.withToken(instance.getToken());
      this.withType(instance.getType());
      this.withUrl(instance.getUrl());
    }
  }
  private String token;
  private String type;
  private String url;
  public String getToken() {
    return this.token;
  }
  public A withToken(String token) {
    this.token=token; return (A) this;
  }
  public boolean hasToken() {
    return this.token != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public boolean hasType() {
    return this.type != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeFluent that = (ACMEChallengeFluent) o;
    if (!java.util.Objects.equals(token, that.token)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(token,  type,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (token != null) { sb.append("token:"); sb.append(token + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeFluent<A extends ACMEChallengeFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeFluent() {
  }
  
  public ACMEChallengeFluent(ACMEChallenge instance) {
    this.copyInstance(instance);
  }
  private String token;
  private String type;
  private String url;
  
  protected void copyInstance(ACMEChallenge instance) {
    instance = (instance != null ? instance : new ACMEChallenge());
  
    if (instance != null) {
        this.withToken(instance.getToken());
        this.withType(instance.getType());
        this.withUrl(instance.getUrl());
        this.withToken(instance.getToken());
        this.withType(instance.getType());
        this.withUrl(instance.getUrl());
      }
  }
  
  public String getToken() {
    return this.token;
  }
  
  public A withToken(String token) {
    this.token=token; return (A) this;
  }
  
  public boolean hasToken() {
    return this.token != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeFluent that = (ACMEChallengeFluent) o;
    if (!java.util.Objects.equals(token, that.token)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(url, that.url)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(token,  type,  url,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (token != null) { sb.append("token:"); sb.append(token + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  

}
